/// <reference types="mirai" />
/// <reference types="response" />
import { TypedEvent } from "../utils/typed-event";
declare class MiraiInstance {
    options: IMiraiOptions;
    sessionKey: string;
    msgBus: TypedEvent<IMiraiMessagePrivate | IMiraiMessageGroup>;
    eventBus: TypedEvent<IMiraiEvent>;
    status: number;
    constructor(options: IMiraiOptions);
    protected init(): Promise<void>;
    onListenMessage({ msgCallback, eventCallback }: {
        msgCallback?: (msg: IMiraiMessagePrivate | IMiraiMessageGroup) => void;
        eventCallback?: (event: IMiraiEvent) => void;
    }): Promise<void>;
    private _getWsHost;
    protected start(): Promise<void>;
    release(): Promise<any>;
    sendFriendMessage({ target, messageChain }: {
        target: number;
        messageChain: MessageChains;
    }): Promise<IResponse.ISendMsgResponse>;
    sendGroupMessage({ target, messageChain }: {
        target: number;
        messageChain: MessageChains;
    }): Promise<IResponse.ISendMsgResponse>;
    sendMessage({ qq, groupId, messageChain }: {
        qq?: number;
        groupId: number;
        messageChain: MessageChains;
    }): Promise<void>;
    sendImageMessage({ target, qq, groupId, urls }: {
        target: number;
        qq: number;
        groupId: number;
        urls: string[];
    }): Promise<IResponse.ISendImageMessage>;
    recall({ messageId }: {
        messageId: number;
    }): Promise<{
        code: number;
        msg: string;
    }>;
    getMessageFromId(id: number): Promise<IMiraiMessagePrivate | IMiraiMessageGroup | IMiraiEvent>;
    getFriendList(): Promise<{
        id: number;
        nickname: string;
        remark: string;
    }[]>;
    getGroupList(): Promise<any[]>;
    getMemberList(groupId: number): Promise<{
        id: number;
        memberName: string;
        permission: string;
        group: {
            id: number;
            name: string;
            permission: string;
        };
    }>;
    setMuteAll(groupId: number): Promise<IResponse.IResponseBase<"">>;
    unMuteAll(groupId: number): Promise<IResponse.IResponseBase<"">>;
    mute(groupId: number, memberId: number, time: number): Promise<IResponse.IResponseBase<"">>;
    unMute(groupId: number, memberId: number): Promise<IResponse.IResponseBase<"">>;
    kick(groupId: number, memberId: number, msg?: string): Promise<IResponse.IResponseBase<"">>;
    setGroupConfig({ groupId, allowMemberInvite, confessTalk, announcement, anonymousChat, autoApprove, name }: {
        groupId: number;
        name: string;
        announcement: string;
        confessTalk: boolean;
        allowMemberInvite: boolean;
        autoApprove: boolean;
        anonymousChat: boolean;
    }): Promise<IResponse.IResponseBase<"">>;
    getGroupConfig(groupId: number): Promise<IGroupConfig>;
    setMemberInfo({ groupId, memberId, info }: {
        groupId: number;
        memberId: number;
        info: IGroupMemberInfo;
    }): Promise<IResponse.IResponseBase<"">>;
    getMemberInfo(groupId: number, memberId: number): Promise<IGroupMemberInfo>;
}
export default MiraiInstance;
