"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("../modules/axios"));
const log_1 = __importDefault(require("../utils/log"));
const SignIn_1 = __importDefault(require("./SignIn"));
const typed_event_1 = require("../utils/typed-event");
const WebSocket = require("websocket").w3cwebsocket;
class MiraiInstance {
    constructor(options) {
        this.msgBus = new typed_event_1.TypedEvent();
        this.eventBus = new typed_event_1.TypedEvent();
    }
    init() {
        return __awaiter(this, void 0, void 0, function* () {
            this.sessionKey = yield SignIn_1.default.auth(this.options.authKey);
            if (this.sessionKey) {
                this.status = yield SignIn_1.default.verify({
                    sessionKey: this.sessionKey,
                    qq: this.options.qq
                });
            }
            if (this.status === 0) {
                this.start();
            }
        });
    }
    onListenMessage({ msgCallback, eventCallback }) {
        return __awaiter(this, void 0, void 0, function* () {
            this.msgBus.on((msg) => {
                msgCallback && msgCallback(msg);
            });
            this.eventBus.on((event) => {
                eventCallback && eventCallback(event);
            });
        });
    }
    _getWsHost() {
        return __awaiter(this, void 0, void 0, function* () {
            const { enableEvent, enableMsg } = this.options;
            let wsHost = "";
            if (enableEvent && enableMsg) {
                wsHost = `ws://${this.options.host}:${this.options.port}/all?sessionKey=${this.sessionKey}`;
            }
            else if (!enableEvent && enableMsg) {
                wsHost = `ws://${this.options.host}:${this.options.port}/message?sessionKey=${this.sessionKey}`;
            }
            else if (enableEvent && !enableMsg) {
                wsHost = `ws://${this.options.host}:${this.options.port}/event?sessionKey=${this.sessionKey}`;
            }
            console.log(wsHost);
            return wsHost;
        });
    }
    start() {
        return __awaiter(this, void 0, void 0, function* () {
            log_1.default.Info("开始监听消息");
            const { sessionKey } = this;
            const url = `/fetchMessage?sessionKey=${sessionKey}&count=10`;
            if (this.options.enableWebsocket) {
                const self = this;
                const wsHost = yield this._getWsHost();
                const client = new WebSocket(wsHost);
                client.onmessage = function (res) {
                    const data = JSON.parse(res.data);
                    const type = data.type;
                    if (type.indexOf("Message") > -1)
                        self.msgBus.emit(data);
                    if (type.indexOf("Event") > -1)
                        self.eventBus.emit(data);
                };
            }
            else {
                setInterval(() => __awaiter(this, void 0, void 0, function* () {
                    const res = yield axios_1.default.get(url);
                    console.log("res", res.data);
                }), 2000);
            }
        });
    }
    release() {
        return __awaiter(this, void 0, void 0, function* () {
            const { sessionKey } = this;
            const qq = this.options.qq;
            const url = "/release";
            const res = yield axios_1.default.post(url, {
                sessionKey,
                qq
            });
            if (res.data.code === 0) {
                return res.data.code;
            }
            else {
                log_1.default.Error(res.data.msg);
                return -1;
            }
        });
    }
    sendFriendMessage({ target, messageChain }) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "/sendFriendMessage";
            const res = yield axios_1.default.post(url, {
                sessionKey: this.sessionKey,
                target,
                messageChain
            });
            const data = res.data;
            if (data.code === 0) {
                log_1.default.Info("发送成功");
                return data;
            }
            else {
                log_1.default.Error("发送失败：", data.msg);
            }
        });
    }
    sendGroupMessage({ target, messageChain }) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "/sendGroupMessage";
            const res = yield axios_1.default.post(url, {
                sessionKey: this.sessionKey,
                target,
                messageChain
            });
            const data = res.data;
            if (data.code === 0) {
                log_1.default.Info("发送成功");
                return data;
            }
            else {
                log_1.default.Error("发送失败：", data.msg);
            }
        });
    }
    sendMessage({ qq, groupId, messageChain }) {
        return __awaiter(this, void 0, void 0, function* () {
            if (qq) {
                this.sendFriendMessage({
                    target: qq,
                    messageChain
                });
            }
            if (groupId) {
                this.sendGroupMessage({
                    target: groupId,
                    messageChain
                });
            }
        });
    }
    sendImageMessage({ target, qq, groupId, urls }) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "/sendImageMessage";
            const res = yield axios_1.default.post(url, {
                sessionKey: this.sessionKey,
                target,
                qq,
                groupId,
                urls
            });
            return res.data;
        });
    }
    recall({ messageId }) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "/recall";
            const res = yield axios_1.default.post(url, {
                sessionKey: this.sessionKey,
                messageId
            });
            return res.data;
        });
    }
    getMessageFromId(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `/messageFromId?sessionKey=${this.sessionKey}&id=${id}`;
            const res = yield axios_1.default.get(url);
            return res.data;
        });
    }
    getFriendList() {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `/friendList?sessionKey=${this.sessionKey}`;
            const res = yield axios_1.default.get(url);
            return res.data;
        });
    }
    getGroupList() {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `/groupList?sessionKey=${this.sessionKey}`;
            const res = yield axios_1.default.get(url);
            let hash = {};
            return res.data.reduce((pre, cur) => {
                if (!hash[cur.id]) {
                    hash[cur.id] = true;
                    pre.push(cur);
                    return pre;
                }
                return pre;
            }, []);
        });
    }
    getMemberList(groupId) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `/memberList`;
            const res = yield axios_1.default({
                url,
                method: "get",
                params: {
                    target: groupId,
                    sessionKey: this.sessionKey
                }
            });
            return res.data;
        });
    }
    setMuteAll(groupId) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "/muteAll";
            const res = yield axios_1.default.post(url, {
                target: groupId
            });
            return res.data;
        });
    }
    unMuteAll(groupId) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "/unmuteAll";
            const res = yield axios_1.default.post(url, {
                target: groupId
            });
            return res.data;
        });
    }
    mute(groupId, memberId, time) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `/mute`;
            if (time <= 0) {
                return this.unMute(groupId, memberId);
            }
            const res = yield axios_1.default.post(url, {
                target: groupId,
                sessionKey: this.sessionKey,
                memberId,
                time: time || 0
            });
            return res.data;
        });
    }
    unMute(groupId, memberId) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `/unmute`;
            const res = yield axios_1.default.post(url, {
                sessionKey: this.sessionKey,
                target: groupId,
                memberId
            });
            return res.data;
        });
    }
    kick(groupId, memberId, msg = "您已被移出群聊") {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "/kick";
            const res = yield axios_1.default.post(url, {
                sessionKey: this.sessionKey,
                target: groupId,
                memberId,
                msg
            });
            return res.data;
        });
    }
    setGroupConfig({ groupId, allowMemberInvite, confessTalk, announcement, anonymousChat, autoApprove, name }) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `/groupConfig`;
            const res = yield axios_1.default.post(url, {
                target: groupId,
                sessionKey: this.sessionKey,
                config: {
                    allowMemberInvite,
                    confessTalk,
                    announcement,
                    anonymousChat,
                    autoApprove,
                    name
                }
            });
            return res.data;
        });
    }
    getGroupConfig(groupId) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `/groupConfig`;
            const res = yield axios_1.default({
                url,
                method: "get",
                params: {
                    sessionKey: this.sessionKey,
                    target: groupId
                }
            });
            return res.data;
        });
    }
    setMemberInfo({ groupId, memberId, info }) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `/memberInfo`;
            const res = yield axios_1.default.post(url, {
                target: groupId,
                memberId,
                info
            });
            return res.data;
        });
    }
    getMemberInfo(groupId, memberId) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `/memberInfo`;
            const res = yield axios_1.default({
                url,
                method: "get",
                params: {
                    sessionKey: this.sessionKey,
                    target: groupId,
                    memberId
                }
            });
            return res.data;
        });
    }
}
exports.default = MiraiInstance;
//# sourceMappingURL=MiraiInstance.js.map